// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtcore_python.h"

// main header
#include "qurl_wrapper.h"

// Extra includes
#include <QStringList>

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <qbytearray.h>
#include <qbytearrayview.h>
#include <qurl.h>
#include <qurlquery.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QUrl_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QUrl >()))
        return -1;

    ::QUrl *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:QUrl", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QUrl::QUrl()
    // 1: QUrl::QUrl(QString,QUrl::ParsingMode=)
    // 2: QUrl::QUrl(QUrl)
    if (numArgs == 0) {
        overloadId = 0; // QUrl()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QUrl(QString,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // QUrl(QString,QUrl::ParsingMode)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))) {
        overloadId = 2; // QUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QUrl()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }

            if (Shiboken::Errors::occurred() == nullptr) {
                // QUrl()
                cptr = new ::QUrl();
            }
            break;
        }
        case 1: // QUrl(const QString &url, QUrl::ParsingMode mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::TolerantMode);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QUrl(QString,QUrl::ParsingMode)
                cptr = new ::QUrl(cppArg0, cppArg1);
            }
            break;
        }
        case 2: // QUrl(const QUrl &copy)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QUrl cppArg0_local;
            ::QUrl *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QUrl(QUrl)
                cptr = new ::QUrl(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QUrl >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QUrlFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __reduce__()
            // Begin code injection
            // TEMPLATE - reduce_code - START
            pyResult = Py_BuildValue("(N(s))", PyObject_Type(self), qPrintable(cppSelf->toString()));
            // TEMPLATE - reduce_code - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __repr__()
            // Begin code injection
            // TEMPLATE - repr_code - START
            QString format = QString::asprintf("%s('%s')",
                Py_TYPE(self)->tp_name, qPrintable(cppSelf->toString()));
            pyResult = Shiboken::String::fromCString(qPrintable(format));
            // TEMPLATE - repr_code - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_adjusted(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrl::adjusted(QFlags<QUrl::ComponentFormattingOption>)const->QUrl
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // adjusted(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "adjusted", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0 = QFlags<QUrl::ComponentFormattingOption>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // adjusted(QFlags<QUrl::ComponentFormattingOption>)const
            QUrl cppResult = const_cast<const ::QUrl *>(cppSelf)->adjusted(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_authority(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "authority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:authority", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::authority(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // authority(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // authority(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "authority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "authority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "authority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "authority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::ComponentFormattingOption::PrettyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // authority(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->authority(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // clear()
            cppSelf->clear();
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_errorString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // errorString()const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->errorString();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_fileName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fileName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:fileName", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::fileName(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // fileName(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // fileName(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fileName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fileName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "fileName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fileName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::ComponentFormattingOption::FullyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fileName(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->fileName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_fragment(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fragment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:fragment", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::fragment(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // fragment(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // fragment(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fragment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fragment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "fragment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fragment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::ComponentFormattingOption::PrettyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fragment(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->fragment(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_fromAce(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromAce", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromAce", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QUrl::fromAce(QByteArray,QFlags<QUrl::AceProcessingOption>=)->QString
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromAce(QByteArray,QFlags<QUrl::AceProcessingOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_AceProcessingOption_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // fromAce(QByteArray,QFlags<QUrl::AceProcessingOption>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromAce", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromAce", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_AceProcessingOption_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "fromAce", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromAce", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFlags<QUrl::AceProcessingOption> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromAce(QByteArray,QFlags<QUrl::AceProcessingOption>)
            QString cppResult = ::QUrl::fromAce(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_fromEncoded(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromEncoded", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QUrl::fromEncoded(QByteArrayView,QUrl::ParsingMode=)->QUrl
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromEncoded(QByteArrayView,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // fromEncoded(QByteArrayView,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromEncoded", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::TolerantMode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromEncoded(QByteArrayView,QUrl::ParsingMode)
            QUrl cppResult = ::QUrl::fromEncoded(QByteArrayView(cppArg0), cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_fromLocalFile(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QUrl::fromLocalFile(PyPathLike)->QUrl
    if (Shiboken::String::checkPath(pyArg)) {
        overloadId = 0; // fromLocalFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromLocalFile", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromLocalFile(QString)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
            auto cppArg0 = PySide::pyPathToQString(pyArg);
            // END of custom code block [file: ../glue/qtcore.cpp (qfile-path-1)]
            // ========================================================================
            // End of code injection

            QUrl cppResult = ::QUrl::fromLocalFile(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_fromPercentEncoding(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QUrl::fromPercentEncoding(QByteArray)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // fromPercentEncoding(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromPercentEncoding", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fromPercentEncoding(QByteArray)
            QString cppResult = ::QUrl::fromPercentEncoding(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_fromStringList(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromStringList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:fromStringList", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QUrl::fromStringList(QStringList,QUrl::ParsingMode=)->QList<QUrl>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromStringList(QStringList,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // fromStringList(QStringList,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromStringList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromStringList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "fromStringList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromStringList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QStringList cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::TolerantMode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromStringList(QStringList,QUrl::ParsingMode)
            QList<QUrl> cppResult = ::QUrl::fromStringList(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QUrl_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_fromUserInput(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromUserInput", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:fromUserInput", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QUrl::fromUserInput(QString,const QString&=,QFlags<QUrl::UserInputResolutionOption>=)->QUrl
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // fromUserInput(QString,QString,QFlags<QUrl::UserInputResolutionOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // fromUserInput(QString,QString,QFlags<QUrl::UserInputResolutionOption>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_UserInputResolutionOption_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 0; // fromUserInput(QString,QString,QFlags<QUrl::UserInputResolutionOption>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromUserInput", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_workingDirectory = Shiboken::String::createStaticString("workingDirectory");
            if (PyDict_Contains(kwds, key_workingDirectory) != 0) {
                value = PyDict_GetItem(kwds, key_workingDirectory);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_workingDirectory);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromUserInput", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "fromUserInput", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_workingDirectory);
            }
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromUserInput", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_UserInputResolutionOption_IDX])))->flagsConverter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "fromUserInput", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromUserInput", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<QUrl::UserInputResolutionOption> cppArg2(QUrl::UserInputResolutionOption::DefaultResolution);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromUserInput(QString,QString,QFlags<QUrl::UserInputResolutionOption>)
            QUrl cppResult = ::QUrl::fromUserInput(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_hasFragment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasFragment()const
            bool cppResult = const_cast<const ::QUrl *>(cppSelf)->hasFragment();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_hasQuery(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasQuery()const
            bool cppResult = const_cast<const ::QUrl *>(cppSelf)->hasQuery();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_host(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "host", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:host", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::host(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // host(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // host(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "host", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arg__1 = Shiboken::String::createStaticString("arg__1");
            if (PyDict_Contains(kwds, key_arg__1) != 0) {
                value = PyDict_GetItem(kwds, key_arg__1);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_arg__1);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "host", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "host", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_arg__1);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "host", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::ComponentFormattingOption::FullyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // host(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->host(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_idnWhitelist(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // idnWhitelist()
            QStringList cppResult = ::QUrl::idnWhitelist();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isEmpty()const
            bool cppResult = const_cast<const ::QUrl *>(cppSelf)->isEmpty();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_isLocalFile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isLocalFile()const
            bool cppResult = const_cast<const ::QUrl *>(cppSelf)->isLocalFile();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_isParentOf(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrl::isParentOf(QUrl)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // isParentOf(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isParentOf", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isParentOf(QUrl)const
            bool cppResult = const_cast<const ::QUrl *>(cppSelf)->isParentOf(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_isRelative(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isRelative()const
            bool cppResult = const_cast<const ::QUrl *>(cppSelf)->isRelative();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValid()const
            bool cppResult = const_cast<const ::QUrl *>(cppSelf)->isValid();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_matches(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "matches", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::matches(QUrl,QFlags<QUrl::ComponentFormattingOption>)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[1])))) {
        overloadId = 0; // matches(QUrl,QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "matches", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QFlags<QUrl::ComponentFormattingOption> cppArg1 = QFlags<QUrl::ComponentFormattingOption>(0);
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // matches(QUrl,QFlags<QUrl::ComponentFormattingOption>)const
            bool cppResult = const_cast<const ::QUrl *>(cppSelf)->matches(*cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_password(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "password", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:password", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::password(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // password(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // password(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "password", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arg__1 = Shiboken::String::createStaticString("arg__1");
            if (PyDict_Contains(kwds, key_arg__1) != 0) {
                value = PyDict_GetItem(kwds, key_arg__1);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_arg__1);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "password", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "password", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_arg__1);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "password", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::ComponentFormattingOption::FullyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // password(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->password(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_path(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "path", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:path", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::path(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // path(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // path(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "path", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "path", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "path", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "path", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::ComponentFormattingOption::FullyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // path(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->path(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_port(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "port", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:port", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::port(int=)const->int
    if (numArgs == 0) {
        overloadId = 0; // port(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // port(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "port", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_defaultPort = Shiboken::String::createStaticString("defaultPort");
            if (PyDict_Contains(kwds, key_defaultPort) != 0) {
                value = PyDict_GetItem(kwds, key_defaultPort);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_defaultPort);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "port", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "port", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_defaultPort);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "port", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        int cppArg0 = -1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // port(int)const
            int cppResult = const_cast<const ::QUrl *>(cppSelf)->port(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_query(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "query", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:query", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::query(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // query(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // query(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "query", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arg__1 = Shiboken::String::createStaticString("arg__1");
            if (PyDict_Contains(kwds, key_arg__1) != 0) {
                value = PyDict_GetItem(kwds, key_arg__1);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_arg__1);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "query", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "query", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_arg__1);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "query", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::ComponentFormattingOption::PrettyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // query(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->query(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_resolved(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrl::resolved(QUrl)const->QUrl
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // resolved(QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resolved", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // resolved(QUrl)const
            QUrl cppResult = const_cast<const ::QUrl *>(cppSelf)->resolved(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_scheme(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // scheme()const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->scheme();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_setAuthority(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setAuthority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setAuthority", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::setAuthority(QString,QUrl::ParsingMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setAuthority(QString,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setAuthority(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setAuthority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setAuthority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setAuthority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setAuthority", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::TolerantMode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAuthority(QString,QUrl::ParsingMode)
            cppSelf->setAuthority(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_setFragment(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setFragment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setFragment", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::setFragment(QString,QUrl::ParsingMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFragment(QString,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setFragment(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFragment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setFragment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setFragment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setFragment", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::TolerantMode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFragment(QString,QUrl::ParsingMode)
            cppSelf->setFragment(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_setHost(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setHost", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setHost", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::setHost(QString,QUrl::ParsingMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setHost(QString,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setHost(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setHost", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setHost", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setHost", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setHost", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::DecodedMode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHost(QString,QUrl::ParsingMode)
            cppSelf->setHost(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_setIdnWhitelist(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QUrl::setIdnWhitelist(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setIdnWhitelist(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIdnWhitelist", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIdnWhitelist(QStringList)
            ::QUrl::setIdnWhitelist(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_setPassword(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setPassword", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setPassword", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::setPassword(QString,QUrl::ParsingMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setPassword(QString,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setPassword(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPassword", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setPassword", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setPassword", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setPassword", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::DecodedMode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPassword(QString,QUrl::ParsingMode)
            cppSelf->setPassword(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_setPath(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setPath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setPath", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::setPath(QString,QUrl::ParsingMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setPath(QString,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setPath(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setPath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setPath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setPath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setPath", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::DecodedMode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPath(QString,QUrl::ParsingMode)
            cppSelf->setPath(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_setPort(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrl::setPort(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPort(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPort", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPort(int)
            cppSelf->setPort(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_setQuery(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setQuery", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setQuery", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::setQuery(QString,QUrl::ParsingMode=)
    // 1: QUrl::setQuery(QUrlQuery)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrlQuery_IDX]), (pyArgs[0])))) {
        overloadId = 1; // setQuery(QUrlQuery)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setQuery(QString,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setQuery(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setQuery", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setQuery(const QString &query, QUrl::ParsingMode mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setQuery", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "setQuery", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setQuery", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::TolerantMode);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setQuery(QString,QUrl::ParsingMode)
                cppSelf->setQuery(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setQuery(const QUrlQuery &query)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setQuery", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QUrlQuery cppArg0_local;
            ::QUrlQuery *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setQuery(QUrlQuery)
                cppSelf->setQuery(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_setScheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrl::setScheme(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setScheme(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScheme", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setScheme(QString)
            cppSelf->setScheme(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_setUrl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setUrl", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setUrl", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::setUrl(QString,QUrl::ParsingMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setUrl(QString,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setUrl(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setUrl", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setUrl", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setUrl", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setUrl", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::TolerantMode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUrl(QString,QUrl::ParsingMode)
            cppSelf->setUrl(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_setUserInfo(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setUserInfo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setUserInfo", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::setUserInfo(QString,QUrl::ParsingMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setUserInfo(QString,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setUserInfo(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setUserInfo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setUserInfo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setUserInfo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setUserInfo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::TolerantMode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUserInfo(QString,QUrl::ParsingMode)
            cppSelf->setUserInfo(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_setUserName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setUserName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setUserName", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::setUserName(QString,QUrl::ParsingMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setUserName(QString,QUrl::ParsingMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setUserName(QString,QUrl::ParsingMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setUserName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setUserName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setUserName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setUserName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QUrl::ParsingMode cppArg1(QUrl::ParsingMode::DecodedMode);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUserName(QString,QUrl::ParsingMode)
            cppSelf->setUserName(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QUrl::swap(QUrl&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QUrl&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QUrl&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QUrlFunc_toAce(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toAce", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:toAce", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QUrl::toAce(QString,QFlags<QUrl::AceProcessingOption>=)->QByteArray
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // toAce(QString,QFlags<QUrl::AceProcessingOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_AceProcessingOption_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // toAce(QString,QFlags<QUrl::AceProcessingOption>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toAce", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toAce", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_AceProcessingOption_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "toAce", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toAce", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QUrl::AceProcessingOption> cppArg1{};
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toAce(QString,QFlags<QUrl::AceProcessingOption>)
            QByteArray cppResult = ::QUrl::toAce(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_toDisplayString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toDisplayString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:toDisplayString", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::toDisplayString(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toDisplayString(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // toDisplayString(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toDisplayString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toDisplayString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toDisplayString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toDisplayString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0 = QUrl::FormattingOptions(QUrl::ComponentFormattingOption::PrettyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toDisplayString(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->toDisplayString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_toEncoded(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toEncoded", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:toEncoded", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::toEncoded(QFlags<QUrl::ComponentFormattingOption>=)const->QByteArray
    if (numArgs == 0) {
        overloadId = 0; // toEncoded(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // toEncoded(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toEncoded", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toEncoded", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toEncoded", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toEncoded", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::ComponentFormattingOption::FullyEncoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toEncoded(QFlags<QUrl::ComponentFormattingOption>)const
            QByteArray cppResult = const_cast<const ::QUrl *>(cppSelf)->toEncoded(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_toLocalFile(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // toLocalFile()const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->toLocalFile();
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_toPercentEncoding(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toPercentEncoding", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:toPercentEncoding", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QUrl::toPercentEncoding(QString,const QByteArray&=,const QByteArray&=)->QByteArray
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // toPercentEncoding(QString,QByteArray,QByteArray)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // toPercentEncoding(QString,QByteArray,QByteArray)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2])))) {
                overloadId = 0; // toPercentEncoding(QString,QByteArray,QByteArray)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toPercentEncoding", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_exclude = Shiboken::String::createStaticString("exclude");
            if (PyDict_Contains(kwds, key_exclude) != 0) {
                value = PyDict_GetItem(kwds, key_exclude);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_exclude);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toPercentEncoding", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "toPercentEncoding", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_exclude);
            }
            static PyObject *const key_include = Shiboken::String::createStaticString("include");
            if (PyDict_Contains(kwds, key_include) != 0) {
                value = PyDict_GetItem(kwds, key_include);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_include);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toPercentEncoding", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "toPercentEncoding", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_include);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toPercentEncoding", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QByteArray cppArg1_local = QByteArray();
        ::QByteArray *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QByteArray cppArg2_local = QByteArray();
        ::QByteArray *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // toPercentEncoding(QString,QByteArray,QByteArray)
            QByteArray cppResult = ::QUrl::toPercentEncoding(cppArg0, *cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_toString(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:toString", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::toString(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toString(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // toString(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toString", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0 = QUrl::FormattingOptions(QUrl::ComponentFormattingOption::PrettyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toString(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->toString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_toStringList(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toStringList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|OO:toStringList", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QUrl::toStringList(QList<QUrl>,QFlags<QUrl::ComponentFormattingOption>=)->QStringList
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QtCore_QList_QUrl_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // toStringList(QList<QUrl>,QFlags<QUrl::ComponentFormattingOption>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // toStringList(QList<QUrl>,QFlags<QUrl::ComponentFormattingOption>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toStringList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toStringList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "toStringList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toStringList", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QList<QUrl> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QUrl::ComponentFormattingOption> cppArg1 = QUrl::FormattingOptions(QUrl::ComponentFormattingOption::PrettyDecoded);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toStringList(QList<QUrl>,QFlags<QUrl::ComponentFormattingOption>)
            QStringList cppResult = ::QUrl::toStringList(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_url(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "url", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:url", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::url(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // url(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // url(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "url", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "url", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "url", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "url", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0 = QUrl::FormattingOptions(QUrl::ComponentFormattingOption::PrettyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // url(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->url(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_userInfo(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "userInfo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:userInfo", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::userInfo(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // userInfo(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // userInfo(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "userInfo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "userInfo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "userInfo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "userInfo", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::ComponentFormattingOption::PrettyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // userInfo(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->userInfo(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrlFunc_userName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_GET_SIZE(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "userName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    if (PyArg_ParseTuple(args, "|O:userName", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QUrl::userName(QFlags<QUrl::ComponentFormattingOption>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // userName(QFlags<QUrl::ComponentFormattingOption>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // userName(QFlags<QUrl::ComponentFormattingOption>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "userName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "userName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "userName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "userName", errInfo, SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]);
            }
        }
        ::QFlags<QUrl::ComponentFormattingOption> cppArg0(QUrl::ComponentFormattingOption::FullyDecoded);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // userName(QFlags<QUrl::ComponentFormattingOption>)const
            QString cppResult = const_cast<const ::QUrl *>(cppSelf)->userName(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QUrl__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QUrl_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QUrl_EnumFlagInfo[] = {
    "AceProcessingOption:Flag:AceProcessingOptions",
    "ComponentFormattingOption:IntFlag:FormattingOptions",
    "ParsingMode:Enum",
    "UrlFormattingOption:IntFlag",
    "UserInputResolutionOption:Flag:UserInputResolutionOptions",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QUrl_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc___reduce__), METH_NOARGS, nullptr},
    {"adjusted", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_adjusted), METH_O, nullptr},
    {"authority", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_authority), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_clear), METH_NOARGS, nullptr},
    {"errorString", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_errorString), METH_NOARGS, nullptr},
    {"fileName", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_fileName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fragment", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_fragment), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fromAce", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_fromAce), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromEncoded", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_fromEncoded), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromLocalFile", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_fromLocalFile), METH_O|METH_STATIC, nullptr},
    {"fromPercentEncoding", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_fromPercentEncoding), METH_O|METH_STATIC, nullptr},
    {"fromStringList", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_fromStringList), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromUserInput", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_fromUserInput), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"hasFragment", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_hasFragment), METH_NOARGS, nullptr},
    {"hasQuery", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_hasQuery), METH_NOARGS, nullptr},
    {"host", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_host), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"idnWhitelist", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_idnWhitelist), METH_NOARGS|METH_STATIC, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_isEmpty), METH_NOARGS, nullptr},
    {"isLocalFile", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_isLocalFile), METH_NOARGS, nullptr},
    {"isParentOf", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_isParentOf), METH_O, nullptr},
    {"isRelative", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_isRelative), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_isValid), METH_NOARGS, nullptr},
    {"matches", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_matches), METH_VARARGS, nullptr},
    {"password", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_password), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"path", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_path), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"port", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_port), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"query", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_query), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"resolved", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_resolved), METH_O, nullptr},
    {"scheme", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_scheme), METH_NOARGS, nullptr},
    {"setAuthority", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setAuthority), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFragment", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setFragment), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setHost", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setHost), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setIdnWhitelist", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setIdnWhitelist), METH_O|METH_STATIC, nullptr},
    {"setPassword", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setPassword), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setPath", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setPath), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setPort", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setPort), METH_O, nullptr},
    {"setQuery", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setQuery), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setScheme", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setScheme), METH_O, nullptr},
    {"setUrl", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setUrl), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setUserInfo", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setUserInfo), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setUserName", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_setUserName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_swap), METH_O, nullptr},
    {"toAce", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_toAce), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"toDisplayString", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_toDisplayString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toEncoded", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_toEncoded), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toLocalFile", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_toLocalFile), METH_NOARGS, nullptr},
    {"toPercentEncoding", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_toPercentEncoding), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_toString), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toStringList", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_toStringList), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_url), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"userInfo", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_userInfo), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"userName", reinterpret_cast<PyCFunction>(Sbk_QUrlFunc_userName), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QUrl__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QUrl_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
                // operator!=(const QUrl &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUrl cppArg0_local;
                ::QUrl *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
                // operator<(const QUrl &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUrl cppArg0_local;
                ::QUrl *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_LE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
                // operator<=(const QUrl &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUrl cppArg0_local;
                ::QUrl *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf <= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
                // operator==(const QUrl &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUrl cppArg0_local;
                ::QUrl *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        case Py_GT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
                // operator>(const QUrl &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUrl cppArg0_local;
                ::QUrl *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf > (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_GE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
                // operator>=(const QUrl &rhs)
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QUrl cppArg0_local;
                ::QUrl *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf >= (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QUrl_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QUrl_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QUrl_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QUrl_Type = nullptr;
static PyTypeObject *Sbk_QUrl_TypeF(void)
{
    return _Sbk_QUrl_Type;
}

static PyType_Slot Sbk_QUrl_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QUrlFunc___repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QUrl_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QUrl_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QUrl_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QUrl_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QUrl_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QUrl_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QUrl_spec = {
    "2:PySide6.QtCore.QUrl",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QUrl_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QUrl_ParsingMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QUrl::ParsingMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QUrl::ParsingMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QUrl_ParsingMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX])))
        return Enum_PythonToCpp_QUrl_ParsingMode;
    return {};
}

static PyObject *QUrl_ParsingMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QUrl::ParsingMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QUrl::ParsingMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QUrl_UrlFormattingOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QUrl::UrlFormattingOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QUrl::UrlFormattingOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QUrl_UrlFormattingOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_UrlFormattingOption_IDX])))
        return Enum_PythonToCpp_QUrl_UrlFormattingOption;
    return {};
}

static PyObject *QUrl_UrlFormattingOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QUrl::UrlFormattingOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QUrl::UrlFormattingOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_UrlFormattingOption_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QUrl_ComponentFormattingOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QUrl::ComponentFormattingOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QUrl::ComponentFormattingOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QUrl_ComponentFormattingOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ComponentFormattingOption_IDX])))
        return Enum_PythonToCpp_QUrl_ComponentFormattingOption;
    return {};
}

static PyObject *QUrl_ComponentFormattingOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QUrl::ComponentFormattingOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QUrl::ComponentFormattingOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ComponentFormattingOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QUrl_ComponentFormattingOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QUrl::ComponentFormattingOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QUrl::ComponentFormattingOption> *>(cppOut) = value;

}

static PyObject *QUrl_ComponentFormattingOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QUrl::ComponentFormattingOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ComponentFormattingOption_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QUrl_UserInputResolutionOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QUrl::UserInputResolutionOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QUrl::UserInputResolutionOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QUrl_UserInputResolutionOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_UserInputResolutionOption_IDX])))
        return Enum_PythonToCpp_QUrl_UserInputResolutionOption;
    return {};
}

static PyObject *QUrl_UserInputResolutionOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QUrl::UserInputResolutionOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QUrl::UserInputResolutionOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_UserInputResolutionOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QUrl_UserInputResolutionOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QUrl::UserInputResolutionOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QUrl::UserInputResolutionOption> *>(cppOut) = value;

}

static PyObject *QUrl_UserInputResolutionOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QUrl::UserInputResolutionOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_UserInputResolutionOption_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QUrl_AceProcessingOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QUrl::AceProcessingOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QUrl::AceProcessingOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QUrl_AceProcessingOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_AceProcessingOption_IDX])))
        return Enum_PythonToCpp_QUrl_AceProcessingOption;
    return {};
}

static PyObject *QUrl_AceProcessingOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QUrl::AceProcessingOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QUrl::AceProcessingOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_AceProcessingOption_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QUrl_AceProcessingOption(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QUrl::AceProcessingOption>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QUrl::AceProcessingOption> *>(cppOut) = value;

}

static PyObject *QUrl_AceProcessingOption_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QUrl::AceProcessingOption> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_AceProcessingOption_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QUrl_PythonToCpp_QUrl_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QUrl_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QUrl_PythonToCpp_QUrl_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QUrl_TypeF()))
        return QUrl_PythonToCpp_QUrl_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QUrl_PTR_CppToPython_QUrl(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QUrl_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QUrl_COPY_CppToPython_QUrl(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QUrl *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QUrl_TypeF(), new ::QUrl(*source), true, true);
}

// Python to C++ copy conversion.
static void QUrl_PythonToCpp_QUrl_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QUrl *>(cppOut) = *reinterpret_cast< ::QUrl *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QUrl_PythonToCpp_QUrl_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QUrl_TypeF()))
        return QUrl_PythonToCpp_QUrl_COPY;
    return {};
}

// Implicit conversions.
static void constQStringREF_PythonToCpp_QUrl(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QUrl *>(cppOut) = ::QUrl(cppIn);
}
static PythonToCppFunc is_constQStringREF_PythonToCpp_QUrl_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return constQStringREF_PythonToCpp_QUrl;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QUrl_SignatureStrings[] = {
    "2:PySide6.QtCore.QUrl(self)",
    "1:PySide6.QtCore.QUrl(self,url:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.TolerantMode)",
    "0:PySide6.QtCore.QUrl(self,copy:PySide6.QtCore.QUrl)",
    "PySide6.QtCore.QUrl.__reduce__(self)->str",
    "PySide6.QtCore.QUrl.__repr__(self)->str",
    "PySide6.QtCore.QUrl.adjusted(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption)->PySide6.QtCore.QUrl",
    "PySide6.QtCore.QUrl.authority(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.ComponentFormattingOption.PrettyDecoded)->QString",
    "PySide6.QtCore.QUrl.clear(self)",
    "PySide6.QtCore.QUrl.errorString(self)->QString",
    "PySide6.QtCore.QUrl.fileName(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.ComponentFormattingOption.FullyDecoded)->QString",
    "PySide6.QtCore.QUrl.fragment(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.ComponentFormattingOption.PrettyDecoded)->QString",
    "PySide6.QtCore.QUrl.fromAce(domain:typing.Union[PySide6.QtCore.QByteArray, char*],options:PySide6.QtCore.QUrl.AceProcessingOption={})->QString",
    "PySide6.QtCore.QUrl.fromEncoded(input:typing.Union[PySide6.QtCore.QByteArray, char*],mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.TolerantMode)->PySide6.QtCore.QUrl",
    "PySide6.QtCore.QUrl.fromLocalFile(localfile:PyPathLike)->PySide6.QtCore.QUrl",
    "PySide6.QtCore.QUrl.fromPercentEncoding(arg__1:typing.Union[PySide6.QtCore.QByteArray, char*])->QString",
    "PySide6.QtCore.QUrl.fromStringList(uris:QStringList,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.TolerantMode)->QList[PySide6.QtCore.QUrl]",
    "PySide6.QtCore.QUrl.fromUserInput(userInput:QString,workingDirectory:QString=QString(),options:PySide6.QtCore.QUrl.UserInputResolutionOption=QUrl.UserInputResolutionOption.DefaultResolution)->PySide6.QtCore.QUrl",
    "PySide6.QtCore.QUrl.hasFragment(self)->bool",
    "PySide6.QtCore.QUrl.hasQuery(self)->bool",
    "PySide6.QtCore.QUrl.host(self,arg__1:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.ComponentFormattingOption.FullyDecoded)->QString",
    "PySide6.QtCore.QUrl.idnWhitelist()->QStringList",
    "PySide6.QtCore.QUrl.isEmpty(self)->bool",
    "PySide6.QtCore.QUrl.isLocalFile(self)->bool",
    "PySide6.QtCore.QUrl.isParentOf(self,url:typing.Union[PySide6.QtCore.QUrl, QString])->bool",
    "PySide6.QtCore.QUrl.isRelative(self)->bool",
    "PySide6.QtCore.QUrl.isValid(self)->bool",
    "PySide6.QtCore.QUrl.matches(self,url:typing.Union[PySide6.QtCore.QUrl, QString],options:PySide6.QtCore.QUrl.ComponentFormattingOption)->bool",
    "PySide6.QtCore.QUrl.password(self,arg__1:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.ComponentFormattingOption.FullyDecoded)->QString",
    "PySide6.QtCore.QUrl.path(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.ComponentFormattingOption.FullyDecoded)->QString",
    "PySide6.QtCore.QUrl.port(self,defaultPort:int=-1)->int",
    "PySide6.QtCore.QUrl.query(self,arg__1:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.ComponentFormattingOption.PrettyDecoded)->QString",
    "PySide6.QtCore.QUrl.resolved(self,relative:typing.Union[PySide6.QtCore.QUrl, QString])->PySide6.QtCore.QUrl",
    "PySide6.QtCore.QUrl.scheme(self)->QString",
    "PySide6.QtCore.QUrl.setAuthority(self,authority:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.TolerantMode)",
    "PySide6.QtCore.QUrl.setFragment(self,fragment:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.TolerantMode)",
    "PySide6.QtCore.QUrl.setHost(self,host:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.DecodedMode)",
    "PySide6.QtCore.QUrl.setIdnWhitelist(arg__1:QStringList)",
    "PySide6.QtCore.QUrl.setPassword(self,password:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.DecodedMode)",
    "PySide6.QtCore.QUrl.setPath(self,path:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.DecodedMode)",
    "PySide6.QtCore.QUrl.setPort(self,port:int)",
    "1:PySide6.QtCore.QUrl.setQuery(self,query:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.TolerantMode)",
    "0:PySide6.QtCore.QUrl.setQuery(self,query:PySide6.QtCore.QUrlQuery)",
    "PySide6.QtCore.QUrl.setScheme(self,scheme:QString)",
    "PySide6.QtCore.QUrl.setUrl(self,url:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.TolerantMode)",
    "PySide6.QtCore.QUrl.setUserInfo(self,userInfo:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.TolerantMode)",
    "PySide6.QtCore.QUrl.setUserName(self,userName:QString,mode:PySide6.QtCore.QUrl.ParsingMode=QUrl.ParsingMode.DecodedMode)",
    "PySide6.QtCore.QUrl.swap(self,other:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtCore.QUrl.toAce(domain:QString,options:PySide6.QtCore.QUrl.AceProcessingOption={})->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QUrl.toDisplayString(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.FormattingOptions(QUrl.ComponentFormattingOption.PrettyDecoded))->QString",
    "PySide6.QtCore.QUrl.toEncoded(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.ComponentFormattingOption.FullyEncoded)->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QUrl.toLocalFile(self)->QString",
    "PySide6.QtCore.QUrl.toPercentEncoding(arg__1:QString,exclude:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray(),include:typing.Union[PySide6.QtCore.QByteArray, char*]=QByteArray())->PySide6.QtCore.QByteArray",
    "PySide6.QtCore.QUrl.toString(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.FormattingOptions(QUrl.ComponentFormattingOption.PrettyDecoded))->QString",
    "PySide6.QtCore.QUrl.toStringList(uris:QList[PySide6.QtCore.QUrl],options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.FormattingOptions(QUrl.ComponentFormattingOption.PrettyDecoded))->QStringList",
    "PySide6.QtCore.QUrl.url(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.FormattingOptions(QUrl.ComponentFormattingOption.PrettyDecoded))->QString",
    "PySide6.QtCore.QUrl.userInfo(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.ComponentFormattingOption.PrettyDecoded)->QString",
    "PySide6.QtCore.QUrl.userName(self,options:PySide6.QtCore.QUrl.ComponentFormattingOption=QUrl.ComponentFormattingOption.FullyDecoded)->QString",
    "PySide6.QtCore.QUrl.__copy__()",
    nullptr}; // Sentinel
#else
static constexpr size_t QUrl_SignatureByteSize = 850;
static constexpr uint8_t QUrl_SignatureBytes[850] = {
    0x78, 0xda, 0xd5, 0x58, 0x5f, 0x6f, 0xda, 0x30, 0x10, 0x7f, 0xe7, 0x53, 0xf4, 0x31, 0x4c, 0x14,
    0xad, 0x7b, 0xd8, 0x03, 0x12, 0x93, 0xba, 0x52, 0xb4, 0x4a, 0xdd, 0x1a, 0xda, 0x75, 0x7b, 0xa8,
    0xaa, 0xc8, 0x4b, 0x8e, 0xe2, 0xd5, 0x89, 0xb3, 0xb3, 0xdd, 0x2e, 0x9a, 0xf6, 0xdd, 0x67, 0x83,
    0x93, 0x40, 0x1b, 0x07, 0x02, 0x85, 0xb2, 0xa7, 0x24, 0xf6, 0xf9, 0xfe, 0xf9, 0xee, 0x77, 0x77,
    0x79, 0xd7, 0xf3, 0xb3, 0x2b, 0x1a, 0xc1, 0xfb, 0xee, 0x48, 0x9e, 0x70, 0x84, 0xee, 0xe8, 0x1a,
    0x99, 0x27, 0x80, 0x8d, 0xdb, 0xad, 0x23, 0xe7, 0x5e, 0x47, 0x21, 0xeb, 0x8d, 0xae, 0x24, 0xd2,
    0xe4, 0xae, 0x13, 0xf3, 0x08, 0xaa, 0x28, 0xbb, 0x3e, 0x41, 0xa1, 0x09, 0x3e, 0xeb, 0xfd, 0xfe,
    0xd3, 0x85, 0xee, 0x57, 0xce, 0x00, 0x49, 0x22, 0xcd, 0x47, 0xbb, 0xf5, 0xd6, 0x2d, 0x2a, 0xe4,
    0x69, 0x56, 0xb5, 0xdb, 0x6e, 0x55, 0xc9, 0x0c, 0x02, 0x84, 0x48, 0x85, 0x10, 0x04, 0x33, 0x23,
    0x0e, 0x3f, 0x08, 0x89, 0x4e, 0xca, 0x14, 0x97, 0xd3, 0x91, 0xe8, 0xa7, 0x12, 0x12, 0xa2, 0x99,
    0x36, 0x3c, 0x95, 0x94, 0x27, 0xa2, 0xd2, 0xde, 0x13, 0x1e, 0xa7, 0x3c, 0x81, 0x44, 0x0e, 0x39,
    0xc6, 0x44, 0x4a, 0x6d, 0xea, 0xc5, 0x94, 0x5c, 0x73, 0xaf, 0xa0, 0xaf, 0x96, 0xa6, 0xe4, 0x84,
    0x23, 0x95, 0xd9, 0x06, 0xe2, 0xfa, 0xf5, 0xdb, 0x5d, 0x1f, 0x41, 0xca, 0x6c, 0x00, 0xa1, 0x76,
    0x7d, 0xa4, 0x75, 0xb3, 0x17, 0x59, 0xa9, 0x4f, 0xc8, 0x80, 0xa0, 0x8d, 0x87, 0xaa, 0x7d, 0x40,
    0xe4, 0x38, 0x3b, 0x9f, 0x3b, 0xb2, 0x8e, 0xdd, 0x98, 0x32, 0xf8, 0x42, 0x62, 0xd8, 0xa2, 0x75,
    0x43, 0xc5, 0xd8, 0x8a, 0xc6, 0x8d, 0x91, 0xdc, 0xc5, 0x9a, 0xc7, 0x9e, 0xf8, 0x7a, 0x8c, 0x3c,
    0x3e, 0x0e, 0xc1, 0x8b, 0x78, 0x4c, 0x68, 0xd2, 0x93, 0x59, 0xaa, 0x29, 0xbb, 0xd7, 0x89, 0xe6,
    0x73, 0xf3, 0x94, 0xfe, 0x63, 0x26, 0xe1, 0x18, 0x91, 0x64, 0x9d, 0x83, 0x70, 0x42, 0xf0, 0xcd,
    0x6d, 0xad, 0xfa, 0x9a, 0xab, 0x8f, 0x3c, 0x04, 0x21, 0x4a, 0xc5, 0xff, 0xfc, 0x5d, 0x41, 0x9d,
    0xd3, 0x64, 0xaa, 0xb8, 0x47, 0x93, 0x54, 0xc9, 0xa6, 0x1a, 0xbd, 0x00, 0x30, 0xac, 0x9e, 0x38,
    0x46, 0xdb, 0x73, 0x1e, 0x12, 0x36, 0xd4, 0x21, 0xe6, 0x31, 0xf3, 0x66, 0x82, 0x4d, 0xcb, 0xf7,
    0x89, 0x9c, 0x9c, 0xd3, 0xfb, 0xa6, 0xcc, 0x7c, 0xc0, 0x50, 0xdf, 0xe8, 0xd4, 0x03, 0x26, 0xba,
    0x09, 0xde, 0x05, 0xc1, 0x51, 0x43, 0x1f, 0xac, 0xe0, 0xe2, 0xd9, 0xf6, 0x39, 0x15, 0xd2, 0x53,
    0x48, 0x45, 0x0e, 0xab, 0x66, 0xe1, 0x65, 0x3c, 0x38, 0x32, 0xac, 0x6e, 0x2a, 0xb8, 0xdc, 0x3a,
    0x75, 0xba, 0x16, 0x80, 0x67, 0xe6, 0xca, 0x3d, 0x95, 0xbf, 0x15, 0x70, 0xff, 0xc8, 0xf1, 0x5e,
    0x3f, 0x07, 0x14, 0x21, 0x94, 0x1c, 0xb3, 0x7c, 0xa3, 0x6f, 0x9f, 0x5e, 0xbb, 0x36, 0x14, 0x0b,
    0xd6, 0x97, 0x20, 0x38, 0x53, 0x86, 0x70, 0x3e, 0x93, 0x9c, 0xdb, 0xdd, 0x01, 0x8c, 0x89, 0x62,
    0x73, 0xeb, 0x0d, 0xee, 0x73, 0x42, 0xc4, 0x70, 0x3e, 0xd7, 0xf5, 0xd1, 0x1f, 0x9c, 0x3b, 0x69,
    0x47, 0x0a, 0x30, 0x5b, 0x4e, 0xc8, 0x85, 0x45, 0x0e, 0x1b, 0x1a, 0xaf, 0x05, 0x63, 0x34, 0x4a,
    0xbe, 0x4f, 0xa8, 0x04, 0x66, 0x62, 0xa8, 0xa4, 0x35, 0xd7, 0x5e, 0x4d, 0x2f, 0x4e, 0xe3, 0x54,
    0x2e, 0x37, 0x90, 0x8a, 0x32, 0xa1, 0x96, 0xd3, 0xea, 0x08, 0xd4, 0x76, 0x5c, 0x8c, 0xcb, 0x06,
    0xa1, 0x36, 0x55, 0xf4, 0xa1, 0xce, 0x81, 0xd5, 0xf4, 0xb6, 0x9e, 0xf3, 0x25, 0x30, 0x22, 0xe9,
    0xc3, 0x2a, 0x4a, 0x7c, 0x23, 0x8c, 0x46, 0x4b, 0xe9, 0xb4, 0xa7, 0xc3, 0x09, 0x88, 0x75, 0x34,
    0x5d, 0xbb, 0x01, 0x70, 0x2a, 0x93, 0x12, 0x21, 0x74, 0x4e, 0x45, 0x7b, 0x11, 0x4a, 0xa9, 0xc6,
    0xca, 0xfd, 0xa8, 0xcd, 0x29, 0x47, 0x9b, 0x5d, 0xd1, 0x2c, 0xf1, 0x7d, 0xbd, 0xd0, 0xa3, 0x89,
    0xec, 0x1f, 0x1e, 0xe9, 0xa3, 0xfa, 0xa5, 0xf2, 0xd8, 0xaf, 0x22, 0x75, 0xb7, 0xe2, 0xca, 0x26,
    0xe5, 0x1c, 0x0d, 0x52, 0x3d, 0xe4, 0x8d, 0x23, 0xda, 0x20, 0x6e, 0x96, 0x15, 0xab, 0x02, 0x9c,
    0xd0, 0xf1, 0x1c, 0xc3, 0x2a, 0x1d, 0x98, 0x00, 0x79, 0xbc, 0xd8, 0x63, 0x16, 0x2d, 0xe7, 0x8b,
    0x76, 0xf4, 0x0e, 0xd9, 0x0b, 0x30, 0xdc, 0xc9, 0x1b, 0xb0, 0x5d, 0x48, 0xfe, 0x54, 0xc0, 0xb5,
    0x01, 0xee, 0x0d, 0x25, 0xda, 0x08, 0xa8, 0x15, 0x78, 0x36, 0x0f, 0xcb, 0x36, 0x18, 0xe7, 0xa0,
    0xd9, 0x79, 0xce, 0x5f, 0x00, 0x84, 0x1c, 0x1e, 0x76, 0xa0, 0xb0, 0x5f, 0x24, 0xbf, 0x81, 0x81,
    0x5d, 0x08, 0x2c, 0x72, 0x3c, 0xb5, 0xc9, 0xed, 0x18, 0x3a, 0x0d, 0x71, 0x59, 0x94, 0x3b, 0xd3,
    0x24, 0xdf, 0xfe, 0xfc, 0x59, 0x29, 0xb5, 0x82, 0x6e, 0x4a, 0xe3, 0x34, 0xf2, 0xaa, 0x4c, 0xcd,
    0xce, 0x2c, 0x4d, 0x73, 0xcd, 0x9d, 0x47, 0xb6, 0x36, 0x66, 0xbb, 0xe4, 0x4d, 0x9b, 0xae, 0x31,
    0xb7, 0x42, 0xed, 0xd7, 0xae, 0x24, 0x97, 0xf3, 0xa0, 0xb2, 0x5f, 0x5b, 0x0f, 0xbd, 0x47, 0x92,
    0xda, 0x2a, 0x27, 0x27, 0x80, 0x4d, 0x20, 0xb9, 0x92, 0x9f, 0xe4, 0x73, 0x63, 0x5b, 0xae, 0xfb,
    0x5a, 0xf3, 0x98, 0x73, 0xa0, 0x70, 0xc8, 0x1d, 0x50, 0x91, 0x32, 0x92, 0xcd, 0x0d, 0xe0, 0x9b,
    0x14, 0xee, 0xa7, 0xab, 0xc2, 0x6b, 0x54, 0x0e, 0x97, 0x54, 0x1e, 0xc9, 0xf3, 0x69, 0x72, 0xcb,
    0x0d, 0x86, 0x15, 0xb3, 0x86, 0x3b, 0x9f, 0xf5, 0xbb, 0xf5, 0xf6, 0x38, 0x46, 0xc4, 0x3c, 0x02,
    0xe0, 0x77, 0xc8, 0x54, 0x04, 0x0d, 0x47, 0xc6, 0x7e, 0xb9, 0xa4, 0x47, 0x29, 0x9a, 0x6c, 0xcc,
    0x63, 0x0d, 0x3f, 0xfc, 0x27, 0xf1, 0xf4, 0x6c, 0x74, 0x76, 0x4e, 0xba, 0x7b, 0x61, 0x85, 0x73,
    0x20, 0x53, 0x39, 0xde, 0xef, 0xad, 0xaf, 0xd5, 0x42, 0x85, 0x78, 0xf5, 0x3f, 0x65, 0x6a, 0xa1,
    0x6c, 0xbc, 0xf6, 0xa8, 0x12, 0x04, 0xe6, 0x1f, 0x75, 0x10, 0x78, 0xed, 0xd6, 0x3f, 0xdf, 0x43,
    0x7b, 0xd4
};
#endif

PyTypeObject *init_QUrl(PyObject *module)
{
    if (SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX].type != nullptr)
        return SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX].type;

    Shiboken::AutoDecRef Sbk_QUrl_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QUrl_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QUrl",
        "QUrl",
        &Sbk_QUrl_spec,
        &Shiboken::callCppDestructor< ::QUrl >,
        Sbk_QUrl_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QUrl_TypeF(); // references _Sbk_QUrl_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QUrl_SignatureStrings);
#else
    InitSignatureBytes(pyType, QUrl_SignatureBytes, QUrl_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QUrl_PropertyStrings);
    SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QUrl_PythonToCpp_QUrl_PTR,
        is_QUrl_PythonToCpp_QUrl_PTR_Convertible,
        QUrl_PTR_CppToPython_QUrl,
        QUrl_COPY_CppToPython_QUrl);

    Shiboken::Conversions::registerConverterName(converter, "QUrl");
    Shiboken::Conversions::registerConverterName(converter, "QUrl*");
    Shiboken::Conversions::registerConverterName(converter, "QUrl&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QUrl).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QUrl_PythonToCpp_QUrl_COPY,
        is_QUrl_PythonToCpp_QUrl_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        constQStringREF_PythonToCpp_QUrl,
        is_constQStringREF_PythonToCpp_QUrl_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QUrl_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ParsingMode'.
    const char *ParsingMode_Initializer[] = {
        "TolerantMode",
        "StrictMode",
        "DecodedMode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ParsingMode_InitializerValues[] = {
        uint8_t(QUrl::ParsingMode::TolerantMode), //  0x00  0
        uint8_t(QUrl::ParsingMode::StrictMode),   //  0x01  1
        uint8_t(QUrl::ParsingMode::DecodedMode)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QUrl_TypeF(),
        "2:PySide6.QtCore.QUrl.ParsingMode",
        ParsingMode_Initializer, ParsingMode_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ParsingMode_IDX].type = EType;
    // Register converter for enum 'QUrl::ParsingMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QUrl_ParsingMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QUrl_ParsingMode,
            is_Enum_PythonToCpp_QUrl_ParsingMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QUrl::ParsingMode");
        Shiboken::Conversions::registerConverterAlias(converter, "ParsingMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ParsingMode' enum.

    // Initialization of enum 'UrlFormattingOption'.
    const char *UrlFormattingOption_Initializer[] = {
        "None_",
        "RemoveScheme",
        "RemovePassword",
        "RemoveUserInfo",
        "RemovePort",
        "RemoveAuthority",
        "RemovePath",
        "RemoveQuery",
        "RemoveFragment",
        "PreferLocalFile",
        "StripTrailingSlash",
        "RemoveFilename",
        "NormalizePathSegments",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t UrlFormattingOption_InitializerValues[] = {
        uint16_t(QUrl::UrlFormattingOption::None),                 //  0x0000  0
        uint16_t(QUrl::UrlFormattingOption::RemoveScheme),         //  0x0001  1
        uint16_t(QUrl::UrlFormattingOption::RemovePassword),       //  0x0002  2
        uint16_t(QUrl::UrlFormattingOption::RemoveUserInfo),       //  0x0006  6
        uint16_t(QUrl::UrlFormattingOption::RemovePort),           //  0x0008  8
        uint16_t(QUrl::UrlFormattingOption::RemoveAuthority),      //  0x001e  30
        uint16_t(QUrl::UrlFormattingOption::RemovePath),           //  0x0020  32
        uint16_t(QUrl::UrlFormattingOption::RemoveQuery),          //  0x0040  64
        uint16_t(QUrl::UrlFormattingOption::RemoveFragment),       //  0x0080  128
        uint16_t(QUrl::UrlFormattingOption::PreferLocalFile),      //  0x0200  512
        uint16_t(QUrl::UrlFormattingOption::StripTrailingSlash),   //  0x0400  1024
        uint16_t(QUrl::UrlFormattingOption::RemoveFilename),       //  0x0800  2048
        uint16_t(QUrl::UrlFormattingOption::NormalizePathSegments) //  0x1000  4096
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QUrl_TypeF(),
        "2:PySide6.QtCore.QUrl.UrlFormattingOption",
        UrlFormattingOption_Initializer, UrlFormattingOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QUrl_UrlFormattingOption_IDX].type = EType;
    // Register converter for enum 'QUrl::UrlFormattingOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QUrl_UrlFormattingOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QUrl_UrlFormattingOption,
            is_Enum_PythonToCpp_QUrl_UrlFormattingOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QUrl::UrlFormattingOption");
        Shiboken::Conversions::registerConverterAlias(converter, "UrlFormattingOption");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'UrlFormattingOption' enum.

    // Initialization of enum 'ComponentFormattingOption'.
    const char *ComponentFormattingOption_Initializer[] = {
        "PrettyDecoded",
        "EncodeSpaces",
        "EncodeUnicode",
        "EncodeDelimiters",
        "EncodeReserved",
        "DecodeReserved",
        "FullyEncoded",
        "FullyDecoded",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t ComponentFormattingOption_InitializerValues[] = {
        uint32_t(QUrl::ComponentFormattingOption::PrettyDecoded),    //  0x00000000  0
        uint32_t(QUrl::ComponentFormattingOption::EncodeSpaces),     //  0x00100000  1048576
        uint32_t(QUrl::ComponentFormattingOption::EncodeUnicode),    //  0x00200000  2097152
        uint32_t(QUrl::ComponentFormattingOption::EncodeDelimiters), //  0x00c00000  12582912
        uint32_t(QUrl::ComponentFormattingOption::EncodeReserved),   //  0x01000000  16777216
        uint32_t(QUrl::ComponentFormattingOption::DecodeReserved),   //  0x02000000  33554432
        uint32_t(QUrl::ComponentFormattingOption::FullyEncoded),     //  0x01f00000  32505856
        uint32_t(QUrl::ComponentFormattingOption::FullyDecoded)      //  0x07f00000  133169152
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QUrl_TypeF(),
        "2:PySide6.QtCore.QUrl.ComponentFormattingOption",
        ComponentFormattingOption_Initializer, ComponentFormattingOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QUrl_ComponentFormattingOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_ComponentFormattingOption_IDX].type =
        EType;
    // Register converter for enum 'QUrl::ComponentFormattingOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QUrl_ComponentFormattingOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QUrl_ComponentFormattingOption,
            is_Enum_PythonToCpp_QUrl_ComponentFormattingOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QUrl::ComponentFormattingOption");
        Shiboken::Conversions::registerConverterAlias(converter, "ComponentFormattingOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QUrl_ComponentFormattingOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QUrl_ComponentFormattingOption,
            is_Enum_PythonToCpp_QUrl_ComponentFormattingOption_Convertible);
        // Register converter for flag 'QFlags<QUrl::ComponentFormattingOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QUrl::ComponentFormattingOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QUrl::FormattingOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'ComponentFormattingOption' enum/flags.

    // Initialization of enum 'UserInputResolutionOption'.
    const char *UserInputResolutionOption_Initializer[] = {
        "DefaultResolution",
        "AssumeLocalFile",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t UserInputResolutionOption_InitializerValues[] = {
        uint8_t(QUrl::UserInputResolutionOption::DefaultResolution), //  0x00  0
        uint8_t(QUrl::UserInputResolutionOption::AssumeLocalFile)    //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QUrl_TypeF(),
        "2:PySide6.QtCore.QUrl.UserInputResolutionOption",
        UserInputResolutionOption_Initializer, UserInputResolutionOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QUrl_UserInputResolutionOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_UserInputResolutionOption_IDX].type =
        EType;
    // Register converter for enum 'QUrl::UserInputResolutionOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QUrl_UserInputResolutionOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QUrl_UserInputResolutionOption,
            is_Enum_PythonToCpp_QUrl_UserInputResolutionOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QUrl::UserInputResolutionOption");
        Shiboken::Conversions::registerConverterAlias(converter, "UserInputResolutionOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QUrl_UserInputResolutionOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QUrl_UserInputResolutionOption,
            is_Enum_PythonToCpp_QUrl_UserInputResolutionOption_Convertible);
        // Register converter for flag 'QFlags<QUrl::UserInputResolutionOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QUrl::UserInputResolutionOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QUrl::UserInputResolutionOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'UserInputResolutionOption' enum/flags.

    // Initialization of enum 'AceProcessingOption'.
    const char *AceProcessingOption_Initializer[] = {
        "IgnoreIDNWhitelist",
        "AceTransitionalProcessing",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AceProcessingOption_InitializerValues[] = {
        uint8_t(QUrl::AceProcessingOption::IgnoreIDNWhitelist),       //  0x01  1
        uint8_t(QUrl::AceProcessingOption::AceTransitionalProcessing) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QUrl_TypeF(),
        "2:PySide6.QtCore.QUrl.AceProcessingOption",
        AceProcessingOption_Initializer, AceProcessingOption_InitializerValues);
    SbkPySide6_QtCoreTypeStructs[SBK_QUrl_AceProcessingOption_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QUrl_AceProcessingOption_IDX].type =
        EType;
    // Register converter for enum 'QUrl::AceProcessingOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QUrl_AceProcessingOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QUrl_AceProcessingOption,
            is_Enum_PythonToCpp_QUrl_AceProcessingOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QUrl::AceProcessingOption");
        Shiboken::Conversions::registerConverterAlias(converter, "AceProcessingOption");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QUrl_AceProcessingOption_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QUrl_AceProcessingOption,
            is_Enum_PythonToCpp_QUrl_AceProcessingOption_Convertible);
        // Register converter for flag 'QFlags<QUrl::AceProcessingOption>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QUrl::AceProcessingOption>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QUrl::AceProcessingOptions");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'AceProcessingOption' enum/flags.

    qRegisterMetaType< ::QUrl >("QUrl");
    qRegisterMetaType< ::QUrl::ParsingMode >("QUrl::ParsingMode");
    qRegisterMetaType< ::QUrl::UrlFormattingOption >("QUrl::UrlFormattingOption");
    qRegisterMetaType< ::QUrl::ComponentFormattingOption >("QUrl::ComponentFormattingOption");
    qRegisterMetaType< ::QUrl::UserInputResolutionOption >("QUrl::UserInputResolutionOption");
    qRegisterMetaType< ::QUrl::AceProcessingOption >("QUrl::AceProcessingOption");

    return pyType;
}
